#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.contrib.operators.gcs_to_bq import GoogleCloudStorageToBigQueryOperator

import codecs
import json

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
gcs_to_bq_operator.py는 GCS에서 지정한 버킷 안에 존재하는 파일 등의 객체를 BQ 테이블로 load하는 DAG다.
"""

# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='gcs_to_bq_operator',
    default_args=default_args,
    schedule_interval='@once',
)


# GCS의 CSV 파일을 BQ의 dataset=composer로 load한다.
# 여기서는 schema를 json 파일로 정의하고 읽어 들이는 형태로 하고 있다.
# 파라미터의 자세한 내용은 여기를；https://airflow.readthedocs.io/en/1.10.2/integration.html#id123
with codecs.open('/home/airflow/gcs/dags/schema/schema_table_1.json', 'r', 'utf-8') as f:
    schema = json.load(f)
    gcs_to_bq = GoogleCloudStorageToBigQueryOperator(
        task_id='gcs_to_bq',
        bucket='composer_source',
        source_objects=['table_1.csv'],
        source_format='CSV',
        # autodetect=True,
        schema_fields=schema,
        skip_leading_rows=1,
        destination_project_dataset_table='shuwa-gcp-book.composer.table_1',
        create_disposition='CREATE_IF_NEEDED',
        write_disposition='WRITE_APPEND',
        dag=dag,
    )

gcs_to_bq