#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.operators.bash_operator import BashOperator
from airflow.operators.python_operator import PythonOperator

import pendulum
import random
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
xcom.py는 처음에 난수를 생성하고 PythonOperator에서 push한 후에 별도의 PythonOperator 및 BashOperator에서 pull하는 DAG다.
"""

# DAG 객체에서 정의하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='xcom',
    default_args=default_args,
    schedule_interval='@once',
)

# 우선 난수를 생성하는 함수를 정의한다.
def generate_rnd(**kwargs):
    # 난수를 생성시킨다.
    rnd = random.random()
    # rnd를 반환값으로 한다. 그러면 rnd가 xcom_push된다.
    return rnd


# 다음으로 PythonOperator를 정의한다.
operator_1 = PythonOperator(
    task_id='operator_1',
    python_callable=generate_rnd,
    dag=dag,
)

# 받는 쪽에서는 BashOperator의 template로 받는다.
operator_2 = BashOperator(
    task_id='operator_2',
    bash_command='echo "{{ti.xcom_pull(task_ids="operator_1")}}"',
    dag=dag,
)

operator_1 >> operator_2