WITH
  sales AS (
  SELECT
    T.sales_number,
    sales_date,
    department_code,
    store_code,
    customer_code,
    sales_amount,
    consumption_tax_amount,
    item_code,
    sale_unit_price,
    sales_quantity,
    discount_price,
    consumption_tax_rate,
    consumption_tax_price,
    sales_price
  FROM
    composer.sales_header T
  LEFT OUTER JOIN
    composer.sales_detail S
  ON
    T.sales_number = S.sales_number ),
  item AS (
  SELECT
    item_code,
    item_name,
    department_code,
    division_code,
    T.brand_code,
    brand_name,
    T.category_code,
    category_name
  FROM
    composer.item T
  LEFT OUTER JOIN
    composer.brand S1
  ON
    T.brand_code = S1.brand_code
  LEFT OUTER JOIN
    composer.category S2
  ON
    T.category_code = S2.category_code ),
  store AS (
  SELECT
    store_code,
    store_name,
    prefecture_code,
    zip_code,
    store_category
  FROM
    composer.store ),
  customer AS (
  SELECT
    customer_code,
    birthday,
    sex,
    zip_code,
    start_date,
    end_date
  FROM
    composer.customer )
SELECT
  sales.customer_code,
  birthday,
  sex,
  customer.zip_code AS customer_zip_code,
  start_date,
  end_date,
  sales_number,
  sales_date,
  sales.department_code,
  sales.store_code,
  store_name,
  prefecture_code,
  store.zip_code AS store_zip_code,
  store_category,
  sales_amount,
  consumption_tax_amount,
  sales.item_code,
  sale_unit_price,
  sales_quantity,
  discount_price,
  consumption_tax_rate,
  consumption_tax_price,
  sales_price,
  item_name,
  division_code,
  brand_code,
  brand_name,
  category_code,
  category_name
FROM
  sales
LEFT OUTER JOIN
  item
ON
  sales.item_code = item.item_code
LEFT OUTER JOIN
  store
ON
  sales.store_code = store.store_code
LEFT OUTER JOIN
  customer
ON
  sales.customer_code = customer.customer_code